# Changelog

## [1.0.0](https://github.com/NASA-ACROSS/across-client/compare/v1.0.0...v1.0.0) (2026-01-15)


### Features

* **.github:** add across issue and pr templates ([07ba108](https://github.com/NASA-ACROSS/across-client/commit/07ba108e288d122348d928dbfcb3d339c42a0d42))
* **actions:** adding release please action and configuration ([#39](https://github.com/NASA-ACROSS/across-client/issues/39)) ([bcedfcb](https://github.com/NASA-ACROSS/across-client/commit/bcedfcb11590fd6ab6711573fc9df7890b9c666a))
* add example jupyter notebook for accessing SSA data ([a452121](https://github.com/NASA-ACROSS/across-client/commit/a452121fb32ef44cda3342b87628ce1164d04604))
* add example jupyter notebook for accessing SSA data ([b9e3ae9](https://github.com/NASA-ACROSS/across-client/commit/b9e3ae90d5380fde7969097fe4be5359120a50e3))
* add readthedocs documentation ([#41](https://github.com/NASA-ACROSS/across-client/issues/41)) ([6547c6c](https://github.com/NASA-ACROSS/across-client/commit/6547c6cd69baf554ca0e21513a22f93cb6669381))
* add visibility calculator example notebook ([c381b68](https://github.com/NASA-ACROSS/across-client/commit/c381b684b7fc561189d927de43db2224e4ae7e04))
* add visibility calculator sdk functionality to client ([17862c5](https://github.com/NASA-ACROSS/across-client/commit/17862c5c04af78785e71f535864c1ebbc1b4c24a))
* add visibility calculator sdk functionality to client ([4b72cf8](https://github.com/NASA-ACROSS/across-client/commit/4b72cf86a693c744c0da39cb3ff7be84a6ecc1bc))
* adding client to across namespace ([da8c9d7](https://github.com/NASA-ACROSS/across-client/commit/da8c9d7f214eca1c409a7150432ccf08ac0d7d89))
* adding other sdk SSA endpoints ([419fec0](https://github.com/NASA-ACROSS/across-client/commit/419fec09b930477b9e79d20f8249dd56479a6098))
* adding other sdk SSA endpoints ([9003819](https://github.com/NASA-ACROSS/across-client/commit/9003819f6838ec7b7204a699971c1cbfc7cbdc5e))
* adding pagination params to observation.get_many ([bca535c](https://github.com/NASA-ACROSS/across-client/commit/bca535cc804e856861a26c0e3f21c7dfa76ae792))
* **client:** Adding the client wrapper for the sdk ([440a41a](https://github.com/NASA-ACROSS/across-client/commit/440a41a6eaa071aa9a76d3454f01147092aec839))
* default host to be server url ([#43](https://github.com/NASA-ACROSS/across-client/issues/43)) ([b201fda](https://github.com/NASA-ACROSS/across-client/commit/b201fdaadc0cd02f093bb4885b0958da63b1f6a4))
* **legal:** add NASA copyright notices ([7a40e93](https://github.com/NASA-ACROSS/across-client/commit/7a40e93dc60d185cfbaa41599ffc6b8620d4b4f2))
* **legal:** add NASA copyright notices ([b343f1d](https://github.com/NASA-ACROSS/across-client/commit/b343f1d03b6980ba13e1f91ce530eef780e026a6))
* new issue and pr templates ([107f686](https://github.com/NASA-ACROSS/across-client/commit/107f686a57fc7a658e579136fd762a2a1d3c84c7))
* **README:** installation instructions with pypi ([#37](https://github.com/NASA-ACROSS/across-client/issues/37)) ([dbcff39](https://github.com/NASA-ACROSS/across-client/commit/dbcff398d38ae8b8bd732c374a9de7167e20936a))
* update readme ([ffacff2](https://github.com/NASA-ACROSS/across-client/commit/ffacff265fa713aeaefa3746d8b00518418bc0b5))
* updating the README, adding contributing and code of conduct ([331bd3f](https://github.com/NASA-ACROSS/across-client/commit/331bd3f09c10ec160cda67bf159bce746211a208))
* updating the README, adding contributing and code of conduct ([c7bf0fa](https://github.com/NASA-ACROSS/across-client/commit/c7bf0fafb7d4708c4e176310b53c28e59d30c365))
* updating the README, adding contributing and code of conduct ([7bf4c3c](https://github.com/NASA-ACROSS/across-client/commit/7bf4c3c33a8ac36ee15e6fa9c701418c10aeb038))
* updating the README, adding contributing and code of conduct ([3cfb0fb](https://github.com/NASA-ACROSS/across-client/commit/3cfb0fbfa5dcfcf6c13410ce63986ecc696fe038))
* updating the README, adding contributing and code of conduct ([95602dc](https://github.com/NASA-ACROSS/across-client/commit/95602dc185db2f0db659bb5d50b404a67f2a971d))


### Bug Fixes

* add maintainers ([605023d](https://github.com/NASA-ACROSS/across-client/commit/605023de09517a667b380d3a2e253bd9e54beec0))
* change types of ids in apis and tests ([59a78e9](https://github.com/NASA-ACROSS/across-client/commit/59a78e941bda6532b4cae3dea2a140f0a8b45788))
* change types of ids in apis and tests ([4e2748f](https://github.com/NASA-ACROSS/across-client/commit/4e2748f14930729a9502d09c54e35525af626e91))
* missed two ([0be33b7](https://github.com/NASA-ACROSS/across-client/commit/0be33b7a6272cb08f71a0eebf59fe5331b22fd63))
* **org-name:** update organization name ([c065d13](https://github.com/NASA-ACROSS/across-client/commit/c065d13a3c8125d811f75cceb6e792f1d688985b))
* **org-name:** update organization name ([fc13f9b](https://github.com/NASA-ACROSS/across-client/commit/fc13f9bcd5902f45ed65161459610915b6de01f0))
* pyproject.toml ([9f8a1b9](https://github.com/NASA-ACROSS/across-client/commit/9f8a1b92729ef65c5f591c0b0a8a1d2e4786903f))
* removing ssh from gha ([#35](https://github.com/NASA-ACROSS/across-client/issues/35)) ([392370e](https://github.com/NASA-ACROSS/across-client/commit/392370ef1e9b29189bb0ab1fdac1de9148e90557))
* try removing init to fix gh actions ([d2dc1d3](https://github.com/NASA-ACROSS/across-client/commit/d2dc1d3ac76bb08e25bbdac9043b7ea424d76cbc))


### Miscellaneous Chores

* release 1.0.0 ([b1c1e69](https://github.com/NASA-ACROSS/across-client/commit/b1c1e6943a41f708834017b4351bbbbe22f5ffe4))
